LAS-Read-Writer-in-Python
=========================

Laspy is a python library for reading, modifying and creating .LAS LIDAR files. 
It was designed for python 2.7

API Documentation and tutorials are available at http://pythonhosted.org/laspy.
Installation is standard:

    >>> python setup.py build
    >>> python setup.py install 

You may need to run these commands as root/administrator. 

